@@ -1,4 +1,4 @@
-/* $Id: system.h,v 7.9 1995/05/20 23:43:24 tom Exp $ */
+/* $Id: system.h,v 7.13 2002/11/22 22:36:55 tom Exp $ */
 
 #ifdef HAVE_CONFIG_H
 
@@ -18,15 +18,14 @@
 #  define SYS_MSDOS 1
 # endif
 
-#define ANSI_PROTOS 1
+# if !defined(SYS_VMS) || !defined(SYS_MSDOS) || defined(WIN32)
+#  define SYS_UNIX 1		/* assume we're autoconfiguring */
+# endif
+
 #define HAVE_STRCHR 1
 
 #endif /* HAVE_CONFIG_H */
 
-#ifndef ANSI_PROTOS
-#define ANSI_PROTOS 0
-#endif
-
 #ifndef HAVE_GETOPT_H
 #define HAVE_GETOPT_H 0
 #endif
@@ -55,25 +54,12 @@
 #define SYS_VMS 0
 #endif
 
-#ifndef DECLARED_GETOPT
-#define DECLARED_GETOPT 0
+#ifndef HAVE_GETOPT_HEADER
+#define HAVE_GETOPT_HEADER 0
 #endif
 
 #ifndef PRINT_ROUNDS_DOWN
 #define PRINT_ROUNDS_DOWN 0
-#endif
-
-	/* Macros that ought to be defined on every system */
-#if ANSI_PROTOS
-#define ARGS(p) p
-#define _ARG(type,name) type name
-#define _DCL(type,name)
-#define NO_ARGS void
-#else
-#define ARGS(p) ()
-#define _ARG(type,name) name
-#define _DCL(type,name) type name;
-#define NO_ARGS
 #endif
 
 #ifdef lint
@@ -94,6 +80,6 @@
 	 * scanning loop...
 	 */
 #if !SYS_UNIX
-extern	int	has_wildcard(char *);
-extern	int	expand_wildcard(char *, int);
+extern int has_wildcard(char *);
+extern int expand_wildcard(char *, int);
 #endif
